==> openshift-model-monitoring-4.13.0-sources.jar: annotations/io/fabric8/openshift/api/model/monitoring/v1/EmbeddedPersistentVolumeClaimFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpec;
import io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatus;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface EmbeddedPersistentVolumeClaimFluent<A extends EmbeddedPersistentVolumeClaimFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public EmbeddedObjectMetadata getMetadata();
    public EmbeddedObjectMetadata buildMetadata();
    public A withMetadata(EmbeddedObjectMetadata metadata);
    public Boolean hasMetadata();
    public EmbeddedPersistentVolumeClaimFluent.MetadataNested<A> withNewMetadata();
    public EmbeddedPersistentVolumeClaimFluent.MetadataNested<A> withNewMetadataLike(EmbeddedObjectMetadata item);
    public EmbeddedPersistentVolumeClaimFluent.MetadataNested<A> editMetadata();
    public EmbeddedPersistentVolumeClaimFluent.MetadataNested<A> editOrNewMetadata();
    public EmbeddedPersistentVolumeClaimFluent.MetadataNested<A> editOrNewMetadataLike(EmbeddedObjectMetadata item);
    public PersistentVolumeClaimSpec getSpec();
    public A withSpec(PersistentVolumeClaimSpec spec);
    public Boolean hasSpec();
    public PersistentVolumeClaimStatus getStatus();
    public A withStatus(PersistentVolumeClaimStatus status);
    public Boolean hasStatus();
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,EmbeddedObjectMetadataFluent<EmbeddedPersistentVolumeClaimFluent.MetadataNested<N>> {

        public N and();
        public N endMetadata();    }


}

==> openshift-model-monitoring-5.3.0-sources.jar: annotations/io/fabric8/openshift/api/model/monitoring/v1/EmbeddedPersistentVolumeClaimFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpec;
import io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatus;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface EmbeddedPersistentVolumeClaimFluent<A extends EmbeddedPersistentVolumeClaimFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public EmbeddedObjectMetadata getMetadata();
    public EmbeddedObjectMetadata buildMetadata();
    public A withMetadata(EmbeddedObjectMetadata metadata);
    public Boolean hasMetadata();
    public EmbeddedPersistentVolumeClaimFluent.MetadataNested<A> withNewMetadata();
    public EmbeddedPersistentVolumeClaimFluent.MetadataNested<A> withNewMetadataLike(EmbeddedObjectMetadata item);
    public EmbeddedPersistentVolumeClaimFluent.MetadataNested<A> editMetadata();
    public EmbeddedPersistentVolumeClaimFluent.MetadataNested<A> editOrNewMetadata();
    public EmbeddedPersistentVolumeClaimFluent.MetadataNested<A> editOrNewMetadataLike(EmbeddedObjectMetadata item);
    public PersistentVolumeClaimSpec getSpec();
    public A withSpec(PersistentVolumeClaimSpec spec);
    public Boolean hasSpec();
    public PersistentVolumeClaimStatus getStatus();
    public A withStatus(PersistentVolumeClaimStatus status);
    public Boolean hasStatus();
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,EmbeddedObjectMetadataFluent<EmbeddedPersistentVolumeClaimFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


}
